/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.IContributionItem;
import org.fortiss.tooling.kernel.extension.ITutorialProvider;
import org.fortiss.tooling.kernel.extension.data.TutorialStep;
import org.fortiss.tooling.kernel.service.ITutorialService;
import org.fortiss.tooling.kernel.ui.ToolingKernelUIActivator;
import org.fortiss.tooling.kernel.ui.extension.ITutorialUIProvider;
import org.fortiss.tooling.kernel.ui.extension.data.TutorialStepUI;
import org.fortiss.tooling.kernel.ui.service.ITutorialUIService;

/**
 * Implementation of {@link ITutorialUIService}.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class TutorialUIService implements ITutorialUIService {

	/** The map from tutorial providers to their UI counter-part. */
	private final Map<Class<? extends ITutorialProvider>, Class<? extends ITutorialUIProvider>> providerMap =
			new HashMap<Class<? extends ITutorialProvider>, Class<? extends ITutorialUIProvider>>();
	/** The map of tutorial UI provider instances. */
	private final Map<Class<? extends ITutorialUIProvider>, ITutorialUIProvider> instanceMap =
			new HashMap<Class<? extends ITutorialUIProvider>, ITutorialUIProvider>();

	/** {@inheritDoc} */
	@Override
	public void registerTutorialUIProvider(Class<? extends ITutorialProvider> nonUIprovider,
			Class<? extends ITutorialUIProvider> uiProvider) {
		if(!providerMap.containsKey(nonUIprovider)) {
			try {
				providerMap.put(nonUIprovider, uiProvider);
				instanceMap.put(uiProvider, uiProvider.newInstance());
			} catch(Exception e) {
				error(ToolingKernelUIActivator.getDefault(),
						"Failed to instantiate tutorial UI provider " + uiProvider.getName() + "!",
						e);
			}
		} else {
			StringBuilder sb = new StringBuilder();
			sb.append("TutorialProvider ").append(nonUIprovider.getName());
			sb.append(" already mapped to ").append(uiProvider.getName());
			sb.append("!");
			error(ToolingKernelUIActivator.getDefault(), sb.toString());
		}
	}

	/** Returns the current tutorial UI provider. */
	private ITutorialUIProvider getCurrentUIProvider() {
		Class<? extends ITutorialProvider> nonUIClass =
				ITutorialService.INSTANCE.getActiveTutorial().getClass();
		return instanceMap.get(providerMap.get(nonUIClass));
	}

	/** {@inheritDoc} */
	@Override
	public boolean elementVisibleInNavigator(EObject element) {
		ITutorialUIProvider p = getCurrentUIProvider();
		if(p.getGlobalUIWhitelistProvider().elementVisibleInNavigator(element)) {
			return true;
		}
		TutorialStep step = ITutorialService.INSTANCE.getActiveTutorialStep();
		if(step instanceof TutorialStepUI) {
			return p.getLocalUIWhitelistProvider((TutorialStepUI)step).elementVisibleInNavigator(
					element);
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean globalDefaultActionsVisible() {
		ITutorialUIProvider p = getCurrentUIProvider();
		if(p.getGlobalUIWhitelistProvider().globalDefaultActionsVisible()) {
			return true;
		}
		TutorialStep step = ITutorialService.INSTANCE.getActiveTutorialStep();
		if(step instanceof TutorialStepUI) {
			return p.getLocalUIWhitelistProvider((TutorialStepUI)step)
					.globalDefaultActionsVisible();
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean contextMenuContributionVisible(EObject element, IContributionItem contribution) {
		ITutorialUIProvider p = getCurrentUIProvider();
		if(p.getGlobalUIWhitelistProvider().contextMenuContributionVisible(element, contribution)) {
			return true;
		}
		TutorialStep step = ITutorialService.INSTANCE.getActiveTutorialStep();
		if(step instanceof TutorialStepUI) {
			return p.getLocalUIWhitelistProvider((TutorialStepUI)step)
					.contextMenuContributionVisible(element, contribution);
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean contextMenuContributionVisible(List<EObject> element,
			IContributionItem contribution) {
		ITutorialUIProvider p = getCurrentUIProvider();
		if(p.getGlobalUIWhitelistProvider().contextMenuContributionVisible(element, contribution)) {
			return true;
		}
		TutorialStep step = ITutorialService.INSTANCE.getActiveTutorialStep();
		if(step instanceof TutorialStepUI) {
			return p.getLocalUIWhitelistProvider((TutorialStepUI)step)
					.contextMenuContributionVisible(element, contribution);
		}
		return false;
	}
}
