/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.presentation;

import static org.fortiss.tooling.kernel.ui.ToolingKernelUIActivator.getImageDescriptor;

import org.eclipse.swt.graphics.Image;
import org.fortiss.tooling.kernel.extension.data.TutorialDefinition;
import org.fortiss.tooling.kernel.extension.data.TutorialStep;

/**
 * A {@link ModelElementLabelProvider} that also handles {@link TutorialDefinition}s and
 * {@link TutorialStep}s.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class TutorialDefinitionModelElementLabelProvider extends ModelElementLabelProvider {

	/** The image for the {@link TutorialDefinition} node. */
	private Image tutorialDefinitionImage;

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if(element instanceof TutorialDefinition) {
			TutorialDefinition def = (TutorialDefinition)element;
			return def.getTitle();
		}
		if(element instanceof TutorialStep) {
			TutorialStep step = (TutorialStep)element;
			return step.getTitle();
		}
		return super.getText(element);
	}

	/** {@inheritDoc} */
	@Override
	public Image getImage(Object element) {
		if(element instanceof TutorialDefinition) {
			if(tutorialDefinitionImage == null) {
				tutorialDefinitionImage = getImageDescriptor("icons/tutorial.gif").createImage();
			}
			return tutorialDefinitionImage;
		}
		// TODO: interactive step images
		return super.getImage(element);
	}
}
